"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startUserContext = startUserContext;
exports.buildUserContextManager = buildUserContextManager;
const browser_core_1 = require("@datadog/browser-core");
const hooks_1 = require("../../hooks");
function startUserContext(hooks, configuration, sessionManager) {
    const userContextManager = buildUserContextManager();
    if (configuration.storeContextsAcrossPages) {
        (0, browser_core_1.storeContextManager)(configuration, userContextManager, 'rum', 1 /* CustomerDataType.User */);
    }
    hooks.register(0 /* HookNames.Assemble */, ({ eventType, startTime }) => {
        const user = userContextManager.getContext();
        const session = sessionManager.findTrackedSession(startTime);
        if (session && session.anonymousId && !user.anonymous_id && !!configuration.trackAnonymousUser) {
            user.anonymous_id = session.anonymousId;
        }
        if ((0, browser_core_1.isEmptyObject)(user)) {
            return hooks_1.SKIPPED;
        }
        return {
            type: eventType,
            usr: user,
        };
    });
    return userContextManager;
}
function buildUserContextManager() {
    return (0, browser_core_1.createContextManager)('user', {
        propertiesConfig: {
            id: { type: 'string' },
            name: { type: 'string' },
            email: { type: 'string' },
        },
    });
}
//# sourceMappingURL=userContext.js.map